@@ -360,19 +360,36 @@ Arnolfini.portletLinks = function ()
 		});
 };
 
+Arnolfini.resizeImg = function (id, scale)
+{
+	$(id).find("img").each(function ()
+			       {
+					var src = $(this).attr('src');
+					var new_src = src.replace(/\/image_.+/g, "/image_"+scale);
+					$(this).attr('src', new_src);
+				});
+}
+
 /*   resizer handler */
 resizer.onResize = function ()
-{
+{	
 	if (resizer.currentMode == "small" || resizer.currentMode == "mobile")
 	{
+		$('#portal-columns').after($("#FrontPageManagerLeft"));
+		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "large");
+		$('#FrontPageManagerLeft').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
 		$('#portal-column-one').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
 		$('#portal-column-two').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
 		
 	}
 	else
 	{
+		$('#FrontPageManagerLeft').masonry( 'destroy' );
+		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "mini");
 		$('#portal-column-one').masonry( 'destroy' );
 		$('#portal-column-two').masonry( 'destroy' );
+		$("#FrontPageManagerRight").after($("#FrontPageManagerLeft"))
+		
 	}
 }
 
