@@ -516,4 +516,26 @@ class CollectionPortlet(CollectionPortletRenderer, CommonBrowserView):
     _template = ViewPageTemplateFile('collection.pt')
     render = _template
 
-    
\ No newline at end of file
+class FrontPageView(FolderListing):
+    """
+    View for the collection in the front page, it has a top section that has a main item of content (later it will be a slideshow)
+    and two portlet managers
+    """
+    def getMainContent(self):
+        """
+        This function returns the first item of the chosen collection.
+        """
+        collection = self.context.restrictedTraverse("/arnolfini/front-page-main")
+        results = collection.queryCatalog()
+        
+        if len(results) > 0:
+            return results[0]
+        else:
+            return None
+        
+    def showManageButton(self):
+        secman = getSecurityManager()
+        if not secman.checkPermission('Portlets: Manage portlets', self.context):
+            return False
+        else:
+            return True
\ No newline at end of file
